Index: trunk/src/config.php
===================================================================
--- trunk/src/config.php	(revision 7759)
+++ trunk/src/config.php	(revision 7765)
@@ -22,7 +22,8 @@
  * Placemark settings. Which icons do you want to use
  */
-$config['placemark_green']	= 'http://svn.wirelessleiden.nl/svn/projects/NodeMap2.0/trunk/src/img/sleutelGroen.png';
-$config['placemark_orange']	= 'img/sleutelOranje.png';
-$config['placemark_red']	= 'img/sleutelRood.png';
+$config['node_green']	= 'http://svn.wirelessleiden.nl/svn/projects/NodeMap2.0/trunk/src/img/sleutelGroen.png';
+$config['node_orange']	= 'img/sleutelOranje.png';
+$config['node_red']		= 'img/sleutelRood.png';
+$config['line_black']	= '#000000ff';
 
 /*
@@ -35,5 +36,6 @@
 $config['require'][]		= $config['folder_class'] . 'FileHandler.class.php';
 $config['require'][]		= $config['folder_class'] . 'KMLFile.class.php';
-$config['require'][]		= $config['folder_class'] . 'KMLPlacemark.class.php';
+$config['require'][]		= $config['folder_class'] . 'KMLNode.class.php';
+$config['require'][]		= $config['folder_class'] . 'KMLLine.class.php';
 
 $config['googlekey'] 		= array();
Index: trunk/src/inc/KMLLine.class.php
===================================================================
--- trunk/src/inc/KMLLine.class.php	(revision 7765)
+++ trunk/src/inc/KMLLine.class.php	(revision 7765)
@@ -0,0 +1,200 @@
+<?php
+/*
+ * Project: NodeMap2.0
+ * File: KMLPlacemark.class.php
+ * Purpose: Placemark used in KMLFile
+ */
+
+define('LINE_BLACK', 'blackLine');
+
+class KMLLine {
+	private $template = '
+		<Placemark id="%ID%">
+			<name>%NAME%</name>
+			<description>
+				<![CDATA[
+					<img src="http://www.wirelessleiden.nl/sites/wirelessleiden.nl/files/garland-wl_logo.png" alt="Wireless Leiden" title="Wireless Leiden" style="float: right;"/>
+					%DESCRIPTION%
+				]]>
+			</description>
+			<LookAt>
+				<longitude>%LONGITUDE%</longitude>
+				<latitude>%LATITUDE%</latitude>
+				<altitude>0</altitude>
+				<heading>0</heading>
+				<tilt>0</tilt>
+				<range>500</range>
+			</LookAt>
+			<styleUrl>%STYLE%</styleUrl>
+			<LineString>
+				<coordinates>
+					%X1%, %Y1%, 0. 
+					%X2%, %Y2%, 0.
+				</coordinates>
+			</LineString>
+		</Placemark>';
+
+	private $id;					// ID of the line
+	private $name;					// Name of the line
+	private $description;			// Description of the line
+	private $longitude;				// Longitude of the line
+	private $latitude;				// Latitude of the line
+	private $style;					// Style of the line
+	private $x1;					// Start X of line
+	private $y1;					// Start Y of line
+	private $x2;					// End X of line
+	private $y2;					// End Y of line
+
+	/*
+	 * Function: __construct (constructor)
+	 * Description: Creating a new KMLLine
+	 * Parameters: -
+	 * Returns: -
+	 */
+	function __construct() {
+		$this->id = '';
+		$this->name = '';
+		$this->description = '';
+		$this->longitude = 0;
+		$this->latitude = 0;
+		$this->style = LINE_BLACK;
+		$this->x1 = 0;
+		$this->y1 = 0;
+		$this->x2 = 0;
+		$this->y2 = 0;
+	}
+
+	/*
+	 * Function: setID
+	 * Description: Setting the ID of the placemark
+	 * Parameters: string $newID
+	 * Returns: -
+	 */
+	function setID($newID) {
+		$this->id = $newID;
+	}
+
+	/*
+	 * Function: setName
+	 * Description: Setting the name of the placemark
+	 * Parameters: string $newName
+	 * Returns: -
+	 */
+	function setName($newName) {
+		$this->name = $newName;
+	}
+
+	/*
+	 * Function: getName
+	 * Description: Getting the name of the placemark
+	 * Parameters: -
+	 * Returns: The name of the placemark
+	 */
+	function getName() {
+		return $this->name;
+	}
+
+	/*
+	 * Function: setDescription
+	 * Description: Setting the description of the placemark
+	 * Parameters: string $newDescription
+	 * Returns: -
+	 */
+	function setDescription($newDescription) {
+		$this->description = (string) $newDescription;
+	}
+
+	/*
+	 * Function: setLongitude
+	 * Description: Setting the longitude of the placemark
+	 * Parameters: double $newLongitude
+	 * Returns: -
+	 */
+	function setLongitude($newLongitude) {
+		$this->longitude = (double) $newLongitude;
+	}
+
+	/*
+	 * Function: setLatitude
+	 * Description: Setting the latitude of the placemark
+	 * Parameters: double $newLatitude
+	 * Returns: -
+	 */
+	function setLatitude($newLatitude) {
+		$this->latitude = (double) $newLatitude;
+	}
+
+	/*
+	 * Function: setStyle
+	 * Description: Setting the style of the placemark
+	 * Parameters: string $newStyle
+	 * Returns: -
+	 */
+	function setStyle($newStyle) {
+		$this->style = (string) $newStyle;
+	}
+
+	/*
+	 * Function: setX1
+	 * Description: Setting the X1 of the placemark
+	 * Parameters: double $newX1
+	 * Returns: -
+	 */
+	function setX1($newX1) {
+		$this->x1 = (double) $newX1;
+	}
+	
+	/*
+	 * Function: setY1
+	 * Description: Setting the Y1 of the placemark
+	 * Parameters: double $newY1
+	 * Returns: -
+	 */
+	function setY1($newY1) {
+		$this->y1 = (double) $newY1;
+	}
+	
+	/*
+	 * Function: setX2
+	 * Description: Setting the X2 of the placemark
+	 * Parameters: double $newX2
+	 * Returns: -
+	 */
+	function setX2($newX2) {
+		$this->x2 = (double) $newX2;
+	}
+	
+	/*
+	 * Function: setY2
+	 * Description: Setting the Y2 of the placemark
+	 * Parameters: double $newY2
+	 * Returns: -
+	 */
+	function setY2($newY2) {
+		$this->y2 = (double) $newY2;
+	}
+
+	/*
+	 * Function: toString
+	 * Description: Converts the content of this placemark to a KML valid string
+	 * Parameters: -
+	 * Returns: KML valid string
+	 */
+	function toString() {
+		$toString = $this->template;
+
+		$toString = str_replace('%ID%', $this->id, $toString);
+		$toString = str_replace('%NAME%', $this->name, $toString);
+		$toString = str_replace('%DESCRIPTION%', $this->description, $toString);
+		$toString = str_replace('%LONGITUDE%', $this->longitude, $toString);
+		$toString = str_replace('%LATITUDE%', $this->latitude, $toString);
+		$toString = str_replace('%STYLE%', $this->style, $toString);
+		$toString = str_replace('%X1%', $this->x1, $toString);
+		$toString = str_replace('%Y1%', $this->y1, $toString);
+		$toString = str_replace('%X2%', $this->x2, $toString);
+		$toString = str_replace('%Y2%', $this->y2, $toString);
+
+		return $toString;
+	}
+}
+?>
Index: trunk/src/inc/KMLNode.class.php
===================================================================
--- trunk/src/inc/KMLNode.class.php	(revision 7765)
+++ trunk/src/inc/KMLNode.class.php	(revision 7765)
@@ -0,0 +1,160 @@
+<?php
+/*
+ * Project: NodeMap2.0
+ * File: KMLNode.class.php
+ * Purpose: Node placemark used in KMLFile
+ */
+
+define('NODE_GREEN', 'greenArrowIcon');
+define('NODE_ORANGE', 'orangeArrowIcon');
+define('NODE_RED', 'redArrowIcon');
+
+class KMLNode {
+	private $template = '
+		<Placemark id="%ID%">
+			<name>%NAME%</name>
+			<description>
+				<![CDATA[
+					<img src="http://www.wirelessleiden.nl/sites/wirelessleiden.nl/files/garland-wl_logo.png" alt="Wireless Leiden" title="Wireless Leiden" style="float: right;"/>
+					%DESCRIPTION%
+				]]>
+			</description>
+			<LookAt>
+				<longitude>%LONGITUDE%</longitude>
+				<latitude>%LATITUDE%</latitude>
+				<altitude>0</altitude>
+				<heading>0</heading>
+				<tilt>0</tilt>
+				<range>500</range>
+			</LookAt>
+			<styleUrl>%STYLE%</styleUrl>
+			<Point>
+				<altitudeMode>relativeToGround</altitudeMode>
+				<coordinates>%LONGITUDE%,%LATITUDE%</coordinates>
+			</Point>
+		</Placemark>';
+
+	private $id;					// ID of the node
+	private $name;					// Name of the node
+	private $descriptionLocation;	// Location information of the node
+	private $descriptionStatus;		// Status information of the node
+	private $longitude;				// Longitude of the node
+	private $latitude;				// Latitude of the node
+	private $style;					// Style of the node
+
+	/*
+	 * Function: __construct (constructor)
+	 * Description: Creating a new KMLNode
+	 * Parameters: -
+	 * Returns: -
+	 */
+	function __construct() {
+		$this->id = '';
+		$this->name = '';
+		$this->descriptionLocation = '';
+		$this->descriptionStatus = '';
+		$this->longitude = 0;
+		$this->latitude = 0;
+		$this->style = 'orangeArrowIcon';
+	}
+
+	/*
+	 * Function: setID
+	 * Description: Setting the ID of the node
+	 * Parameters: string $newID
+	 * Returns: -
+	 */
+	function setID($newID) {
+		$this->id = $newID;
+	}
+
+	/*
+	 * Function: setName
+	 * Description: Setting the name of the node
+	 * Parameters: string $newName
+	 * Returns: -
+	 */
+	function setName($newName) {
+		$this->name = $newName;
+	}
+
+	/*
+	 * Function: getName
+	 * Description: Getting the name of the node
+	 * Parameters: -
+	 * Returns: The name of the node
+	 */
+	function getName() {
+		return $this->name;
+	}
+
+	/*
+	 * Function: setDescriptionLocation
+	 * Description: Setting the location description of the node
+	 * Parameters: string $newDescriptionLocation
+	 * Returns: -
+	 */
+	function setDescriptionLocation($newDescriptionLocation) {
+		$this->descriptionLocation = (string) $newDescriptionLocation;
+	}
+
+	/*
+	 * Function: setDescriptionStatus
+	 * Description: Setting the status description of the node
+	 * Parameters: string $newDescriptionStatus
+	 * Returns: -
+	 */
+	function setDescriptionStatus($newDescriptionStatus) {
+		$this->descriptionStatus = (string) $newDescriptionStatus;
+	}
+
+	/*
+	 * Function: setLongitude
+	 * Description: Setting the longitude of the node
+	 * Parameters: string $newLongitude
+	 * Returns: -
+	 */
+	function setLongitude($newLongitude) {
+		$this->longitude = (double) $newLongitude;
+	}
+
+	/*
+	 * Function: setLatitude
+	 * Description: Setting the latitude of the node
+	 * Parameters: string $newLatitude
+	 * Returns: -
+	 */
+	function setLatitude($newLatitude) {
+		$this->latitude = (double) $newLatitude;
+	}
+
+	/*
+	 * Function: setStyle
+	 * Description: Setting the style of the node
+	 * Parameters: string $newStyle
+	 * Returns: -
+	 */
+	function setStyle($newStyle) {
+		$this->style = (string) $newStyle;
+	}
+
+	/*
+	 * Function: toString
+	 * Description: Converts the content of this node to a KML valid string
+	 * Parameters: -
+	 * Returns: KML valid string
+	 */
+	function toString() {
+		$toString = $this->template;
+
+		$toString = str_replace('%ID%', $this->id, $toString);
+		$toString = str_replace('%NAME%', $this->name, $toString);
+		$toString = str_replace('%DESCRIPTION%', $this->descriptionLocation . $this->descriptionStatus, $toString);
+		$toString = str_replace('%LONGITUDE%', $this->longitude, $toString);
+		$toString = str_replace('%LATITUDE%', $this->latitude, $toString);
+		$toString = str_replace('%STYLE%', $this->style, $toString);
+		
+		return $toString;
+	}
+}
+?>
Index: trunk/src/inc/KMLPlacemark.class.php
===================================================================
--- trunk/src/inc/KMLPlacemark.class.php	(revision 7759)
+++ 	(revision )
@@ -1,160 +1,0 @@
-<?php
-/*
- * Project: NodeMap2.0
- * File: KMLPlacemark.class.php
- * Purpose: Placemark used in KMLFile
- */
-
-define('PLACEMARK_GREEN', 'greenArrowIcon');
-define('PLACEMARK_ORANGE', 'orangeArrowIcon');
-define('PLACEMARK_RED', 'redArrowIcon');
-
-class KMLPlacemark {
-	private $template = '
-		<Placemark id="%ID%">
-			<name>%NAME%</name>
-			<description>
-				<![CDATA[
-					<img src="http://www.wirelessleiden.nl/sites/wirelessleiden.nl/files/garland-wl_logo.png" alt="Wireless Leiden" title="Wireless Leiden" style="float: right;"/>
-					%DESCRIPTION%
-				]]>
-			</description>
-			<LookAt>
-				<longitude>%LONGITUDE%</longitude>
-				<latitude>%LATITUDE%</latitude>
-				<altitude>0</altitude>
-				<heading>0</heading>
-				<tilt>0</tilt>
-				<range>500</range>
-			</LookAt>
-			<styleUrl>%STYLE%</styleUrl>
-			<Point>
-				<altitudeMode>relativeToGround</altitudeMode>
-				<coordinates>%LONGITUDE%,%LATITUDE%</coordinates>
-			</Point>
-		</Placemark>';
-
-	private $id;					// ID of the node
-	private $name;					// Name of the node
-	private $descriptionLocation;	// Location information of the node
-	private $descriptionStatus;		// Status information of the node
-	private $longitude;				// Longitude of the node
-	private $latitude;				// Latitude of the node
-	private $style;					// Style of the placemark
-
-	/*
-	 * Function: __construct (constructor)
-	 * Description: Creating a new KMLFile
-	 * Parameters: -
-	 * Returns: -
-	 */
-	function __construct() {
-		$this->id = '';
-		$this->name = '';
-		$this->descriptionLocation = '';
-		$this->descriptionStatus = '';
-		$this->longitude = 0;
-		$this->latitude = 0;
-		$this->style = 'orangeArrowIcon';
-	}
-
-	/*
-	 * Function: setID
-	 * Description: Setting the ID of the placemark
-	 * Parameters: string $newID
-	 * Returns: -
-	 */
-	function setID($newID) {
-		$this->id = $newID;
-	}
-
-	/*
-	 * Function: setName
-	 * Description: Setting the name of the placemark
-	 * Parameters: string $newName
-	 * Returns: -
-	 */
-	function setName($newName) {
-		$this->name = $newName;
-	}
-
-	/*
-	 * Function: getName
-	 * Description: Getting the name of the placemark
-	 * Parameters: -
-	 * Returns: The name of the placemark
-	 */
-	function getName() {
-		return $this->name;
-	}
-
-	/*
-	 * Function: setDescriptionLocation
-	 * Description: Setting the location description of the placemark
-	 * Parameters: string $newDescriptionLocation
-	 * Returns: -
-	 */
-	function setDescriptionLocation($newDescriptionLocation) {
-		$this->descriptionLocation = (string) $newDescriptionLocation;
-	}
-
-	/*
-	 * Function: setDescriptionStatus
-	 * Description: Setting the status description of the placemark
-	 * Parameters: string $newDescriptionStatus
-	 * Returns: -
-	 */
-	function setDescriptionStatus($newDescriptionStatus) {
-		$this->descriptionStatus = (string) $newDescriptionStatus;
-	}
-
-	/*
-	 * Function: setLongitude
-	 * Description: Setting the longitude of the placemark
-	 * Parameters: string $newLongitude
-	 * Returns: -
-	 */
-	function setLongitude($newLongitude) {
-		$this->longitude = (double) $newLongitude;
-	}
-
-	/*
-	 * Function: setLatitude
-	 * Description: Setting the latitude of the placemark
-	 * Parameters: string $newLatitude
-	 * Returns: -
-	 */
-	function setLatitude($newLatitude) {
-		$this->latitude = (double) $newLatitude;
-	}
-
-	/*
-	 * Function: setStyle
-	 * Description: Setting the style of the placemark
-	 * Parameters: string $newStyle
-	 * Returns: -
-	 */
-	function setStyle($newStyle) {
-		$this->style = (string) $newStyle;
-	}
-
-	/*
-	 * Function: toString
-	 * Description: Converts the content of this placemark to a KML valid string
-	 * Parameters: -
-	 * Returns: KML valid string
-	 */
-	function toString() {
-		$toString = $this->template;
-
-		$toString = str_replace('%ID%', $this->id, $toString);
-		$toString = str_replace('%NAME%', $this->name, $toString);
-		$toString = str_replace('%DESCRIPTION%', $this->descriptionLocation . $this->descriptionStatus, $toString);
-		$toString = str_replace('%LONGITUDE%', $this->longitude, $toString);
-		$toString = str_replace('%LATITUDE%', $this->latitude, $toString);
-		$toString = str_replace('%STYLE%', $this->style, $toString);
-		
-		return $toString;
-	}
-}
-?>
Index: trunk/src/inc/LogHandler.class.php
===================================================================
--- trunk/src/inc/LogHandler.class.php	(revision 7759)
+++ trunk/src/inc/LogHandler.class.php	(revision 7765)
@@ -88,15 +88,15 @@
 			echo '<!-- ' . $errorString . ' -->';
 		}
-		if ($logno <= LOG_LEVEL_WRITE) {			
+		if ((!defined('IGNORE_LOG_LEVEL_WRITE')) && ($logno <= LOG_LEVEL_WRITE)) {
 			$filename = 'logfile.txt';
 			if (is_writable($filename)) {
-				
+
 				//Check if the file can be opened
-				  if (!$handle = fopen($filename, 'w')) {
-				  	define('LOG_LEVEL_WRITE', LOG_LEVEL_NONE);
-					 trigger_log(SYSLOG_EMERG, 'Cannot open file "' . $filename . '"', __FILE__, __LINE__);
-					 exit;
+				if (!$handle = fopen($filename, 'w')) {
+					define('IGNORE_LOG_LEVEL_WRITE', true);
+					trigger_log(SYSLOG_EMERG, 'Cannot open file "' . $filename . '"', __FILE__, __LINE__);
+					exit;
 				}
-			
+					
 				// Write $errorString to file.
 				if (fwrite($handle, $errorString) === FALSE) {
@@ -105,13 +105,13 @@
 					exit;
 				}
-			
+					
 				fclose($handle);
-			
+					
 			} else {
-				define('LOG_LEVEL_WRITE', LOG_LEVEL_NONE);
-					trigger_log(SYSLOG_EMERG, 'Cannot write to "' . $filename . '"', __FILE__, __LINE__);
+				define('IGNORE_LOG_LEVEL_WRITE', true);
+				trigger_log(SYSLOG_EMERG, 'Cannot write to "' . $filename . '"', __FILE__, __LINE__);
 			}
 		}
-		
+
 		if ($logno <= LOG_LEVEL_MAIL) {
 			mail('test@test.com', 'Nodemap error', $errorString);
Index: trunk/src/index.php
===================================================================
--- trunk/src/index.php	(revision 7759)
+++ trunk/src/index.php	(revision 7765)
@@ -25,5 +25,5 @@
 $kmlFile->parseStatusFile($nodeStatus->read());
 
-if ($_GET['write'] == true) {
+if (isset($_GET['write']) && $_GET['write'] == true) {
 	// TODO: David: Write the KML file to a folder with date stamp
 }
Index: trunk/src/logfile.txt
===================================================================
--- trunk/src/logfile.txt	(revision 7759)
+++ trunk/src/logfile.txt	(revision 7765)
@@ -1,2 +1,2 @@
-Debug (8 | 11:55.20 04/14/10 | ): Reading from file "http://watch.wirelessleiden.nl/nagios/export/node-status.csv"
-	In file "D:\Workspace\NodeMap2.0\trunk\src\inc\FileHandler.class.php" on line "42"
+Debug (8 | 13:58.39 04/15/10 | ): Reading from file "http://watch.wirelessleiden.nl/nagios/export/node-status.csv"
+	In file "D:\Werkplaats\NodeMap2.0\trunk\src\inc\FileHandler.class.php" on line "42"

Index: trunk/src/inc/KMLFile.class.php
===================================================================
--- trunk/src/inc/KMLFile.class.php	(revision 7759)
+++ trunk/src/inc/KMLFile.class.php	(revision 7765)
@@ -16,5 +16,5 @@
 					<IconStyle>
 						<Icon>
-							<href>%PLACEMARK_GREEN%</href>
+							<href>%NODE_GREEN%</href>
 						</Icon>
 					</IconStyle>
@@ -23,5 +23,5 @@
 					<IconStyle>
 						<Icon>
-							<href>%PLACEMARK_ORANGE%</href>
+							<href>%NODE_ORANGE%</href>
 						</Icon>
 					</IconStyle>
@@ -30,9 +30,15 @@
 					<IconStyle>
 						<Icon>
-							<href>%PLACEMARK_RED%</href>
+							<href>%NODE_RED%</href>
 						</Icon>
 					</IconStyle>
 				</Style>
-				<Folder>
+				<Style id="blackLine"> 
+					<LineStyle>
+						<color>%LINE_BLACK%</color>
+						<width>3</width>
+					</LineStyle>
+				</Style>
+				<Folder id="nodes">
 					<name>Nodes</name>
 					<description>Nodes from the Wireless Leiden network</description>
@@ -40,12 +46,25 @@
 						<longitude>4.490153</longitude>
 						<latitude>52.161087</latitude>
-						<altitude>0</altitude>
+						<altitude>5</altitude>
 						<heading>0</heading>
 						<tilt>0</tilt>
 						<range>500</range>
 					</LookAt>
-					%CONTENT%
+					%NODESCONTENT%
 				</Folder>
-			</Document>
+				<Folder id="lines">
+					<name>Lines</name>
+					<description>Lines from nodes to nodes from the Wireless Leiden network</description>
+					<LookAt>
+						<longitude>4.490153</longitude>
+						<latitude>52.161087</latitude>
+						<altitude>5</altitude>
+						<heading>0</heading>
+						<tilt>0</tilt>
+						<range>500</range>
+					</LookAt>
+					%LINESCONTENT%
+				</Folder>
+				</Document>
 		</kml>';
 
@@ -55,6 +74,7 @@
 	private $fileContent = array('string', 'string', 'int', 'double', 'int', 'int', 'int', 'int');
 
-	private $KMLPlacemarks;
-
+	private $KMLNodes;
+	private $KMLLines;
+	
 	/*
 	 * Function: __construct (constructor)
@@ -64,15 +84,26 @@
 	 */
 	public function __construct() {
-		$this->KMLPlacemarks = array();
-	}
-
-	/*
-	 * Function: addPlacemark
-	 * Description: Add a placemark to the local placemark array
-	 * Parameters: KMLPlacemark $placemark
+		$this->KMLNodes = array();
+		$this->KMLLines = array();
+	}
+
+	/*
+	 * Function: addNode
+	 * Description: Add a node to the local node array
+	 * Parameters: KMLNode $node
 	 * Returns: -
 	 */
-	public function addPlacemark(KMLPlacemark $placemark) {
-		$this->KMLPlacemarks[] = $placemark;
+	public function addNode(KMLNode $node) {
+		$this->KMLNodes[] = $node;
+	}
+
+	/*
+	 * Function: addLIne
+	 * Description: Add a line to the local line array
+	 * Parameters: KMLLine $line
+	 * Returns: -
+	 */
+	public function addLine(KMLLine $line) {
+		$this->KMLLines[] = $line;
 	}
 
@@ -88,15 +119,23 @@
 		$toString = $this->template;
 
-		$placemarkString = '';
-		$placemarkCount = count($this->KMLPlacemarks);
-		for ($i = 0; $i < $placemarkCount; $i++) {
-			$placemarkString .= $this->KMLPlacemarks[$i]->toString();
-		}
-
-		$toString = str_replace('%PLACEMARK_GREEN%', $config['placemark_green'], $toString);
-		$toString = str_replace('%PLACEMARK_ORANGE%', $config['placemark_orange'], $toString);
-		$toString = str_replace('%PLACEMARK_RED%', $config['placemark_red'], $toString);
-		$toString = str_replace('%CONTENT%', $placemarkString, $toString);
-
+		$nodeString = '';
+		$nodeCount = count($this->KMLNodes);
+		for ($i = 0; $i < $nodeCount; $i++) {
+			$nodeString .= $this->KMLNodes[$i]->toString();
+		}
+
+		$lineString = '';
+		$lineCount = count($this->KMLLines);
+		for ($i = 0; $i < $lineCount; $i++) {
+			$lineString .= $this->KMLLines[$i]->toString();
+		}
+
+		$toString = str_replace('%NODE_GREEN%', $config['node_green'], $toString);
+		$toString = str_replace('%NODE_ORANGE%', $config['node_orange'], $toString);
+		$toString = str_replace('%NODE_RED%', $config['node_red'], $toString);
+		$toString = str_replace('%LINE_BLACK%', $config['line_black'], $toString);
+		$toString = str_replace('%NODESCONTENT%', $nodeString, $toString);
+		$toString = str_replace('%LINESCONTENT%', $lineString, $toString);
+		
 		return $toString;
 	}
@@ -123,13 +162,13 @@
 
 	/*
 	 * Function: getPlacemarkByName
 	 * Description: Find the first KMLPlacemark with the name $name and return its position. If not found, return false
 	 * Parameters: string $name
-	 * Returns: Position of placemark in our array, if not found false
-	 */
-	public function getPlacemarkByName($name) {
-		$nodesCount = count($this->KMLPlacemarks);
+	 * Returns: Position of node in our array, if not found false
+	 */
+	public function getNodeByName($name) {
+		$nodesCount = count($this->KMLNodes);
 		for ($i = 0; $i < $nodesCount; $i++) {
-			if ($this->KMLPlacemarks[$i]->getName() == $name) {
+			if ($this->KMLNodes[$i]->getName() == $name) {
 				return $i;
 			}
@@ -141,5 +180,5 @@
 	/*
 	 * Function: parseLocationFile
 	 * Description: Parse the node location file updating or adding KMLPlacemark objects to the current KMLFile object
 	 * Parameters: string $file
 	 * Returns: true is successfull, otherwise false
@@ -192,12 +231,12 @@
 			$descriptionLocation = 'Naam: ' . $name . '<br/>Locatie: ' . $location . '<br/>Status: ' . $status . '<br/>Latitude: ' . $latitude . '<br/>Longitude: ' . $longitude . '<br/>Interfaces: ' . $interfaces . '<br/>Master IP: ' . $masterip . '<br/>Node type: ' . $nodetype . '<br/><br/>';
 
-			if ($placemarkPosition = $this->getPlacemarkByName($name)) {
+			if ($placemarkPosition = $this->getNodeByName($name)) {
 				// Updating an excisting placemark
-				$this->KMLPlacemarks[$placemarkPosition]->setDescriptionLocation($descriptionLocation);
-				$this->KMLPlacemarks[$placemarkPosition]->setLongitude($longitude);
-				$this->KMLPlacemarks[$placemarkPosition]->setLatitude($latitude);
+				$this->KMLNodes[$placemarkPosition]->setDescriptionLocation($descriptionLocation);
+				$this->KMLNodes[$placemarkPosition]->setLongitude($longitude);
+				$this->KMLNodes[$placemarkPosition]->setLatitude($latitude);
 			} else {
 				// Adding a new placemark
-				$placemark = new KMLPlacemark();
+				$placemark = new KMLNode();
 				$placemark->setID($name);
 				$placemark->setName($name);
@@ -205,5 +244,5 @@
 				$placemark->setLongitude($longitude);
 				$placemark->setLatitude($latitude);
-				$this->addPlacemark($placemark);
+				$this->addNode($placemark);
 			}
 		}
@@ -229,5 +268,5 @@
 	/*
 	 * Function: parseStatusFile
 	 * Description: Parse the node status file updating or adding KMLPlacemark objects to the current KMLFile object
 	 * Parameters: string $file
 	 * Returns: true is successfull, otherwise false
@@ -275,14 +314,14 @@
 			$descriptionStatus = 'Type: ' . $lineContent[0] . '<br/>Host name: ' . $lineContent[1] . '<br/>Has been checked: ' . $lineContent[2] . '<br/>Check execution time: ' . $lineContent[3] . '<br/>Currenr state: ' . $lineContent[4] . '<br/>Last hard state: ' . $lineContent[5] . '<br/>Last check: ' . $lineContent[6] . '<br/>Problem has been acknowledged: ' . $lineContent[7] . '<br/><br/>';
 
-			if ($placemarkPosition = $this->getPlacemarkByName($lineContent[1])) {
+			if ($placemarkPosition = $this->getNodeByName($lineContent[1])) {
 				// Updating an excisting placemark
-				$this->KMLPlacemarks[$placemarkPosition]->setDescriptionStatus($descriptionStatus);
+				$this->KMLNodes[$placemarkPosition]->setDescriptionStatus($descriptionStatus);
 			} else {
 				// Adding a new placemark
-				$placemark = new KMLPlacemark();
+				$placemark = new KMLNode();
 				$placemark->setID($lineContent[1]);
 				$placemark->setName($lineContent[1]);
 				$placemark->setDescriptionStatus($descriptionStatus);
-				$this->addPlacemark($placemark);
+				$this->addNode($placemark);
 			}
 		}
@@ -123,13 +162,13 @@
 
 	/*
-	 * Function: getPlacemarkByName
-	 * Description: Find the first KMLPlacemark with the name $name and return its position. If not found, return false
+	 * Function: getNodeByName
+	 * Description: Find the first KMLNode with the name $name and return its position. If not found, return false
 	 * Parameters: string $name
@@ -141,5 +180,5 @@
 	/*
 	 * Function: parseLocationFile
-	 * Description: Parse the node location file updating or adding KMLPlacemark objects to the current KMLFile object
+	 * Description: Parse the node location file updating or adding KMLNode objects to the current KMLFile object
 	 * Parameters: string $file
 	 * Returns: true is successfull, otherwise false
@@ -229,5 +268,5 @@
 	/*
 	 * Function: parseStatusFile
-	 * Description: Parse the node status file updating or adding KMLPlacemark objects to the current KMLFile object
+	 * Description: Parse the node status file updating or adding KMLNode objects to the current KMLFile object
 	 * Parameters: string $file
 	 * Returns: true is successfull, otherwise false